@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -110,6 +110,42 @@ class DataFusionAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return DataFusionClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> DataFusionTransport:
         """Returns the transport used by the client instance.
@@ -182,6 +218,27 @@ class DataFusionAsyncClient:
         r"""Lists possible versions for Data Fusion instances in
         the specified project and location.
 
+
+        .. code-block:: python
+
+            from google.cloud import data_fusion_v1
+
+            def sample_list_available_versions():
+                # Create a client
+                client = data_fusion_v1.DataFusionClient()
+
+                # Initialize request argument(s)
+                request = data_fusion_v1.ListAvailableVersionsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_available_versions(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.data_fusion_v1.types.ListAvailableVersionsRequest, dict]):
                 The request object. Request message for the list
@@ -211,7 +268,7 @@ class DataFusionAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -264,6 +321,27 @@ class DataFusionAsyncClient:
         r"""Lists Data Fusion instances in the specified project
         and location.
 
+
+        .. code-block:: python
+
+            from google.cloud import data_fusion_v1
+
+            def sample_list_instances():
+                # Create a client
+                client = data_fusion_v1.DataFusionClient()
+
+                # Initialize request argument(s)
+                request = data_fusion_v1.ListInstancesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_instances(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.data_fusion_v1.types.ListInstancesRequest, dict]):
                 The request object. Request message for listing Data
@@ -322,6 +400,25 @@ class DataFusionAsyncClient:
     ) -> datafusion.Instance:
         r"""Gets details of a single Data Fusion instance.
 
+        .. code-block:: python
+
+            from google.cloud import data_fusion_v1
+
+            def sample_get_instance():
+                # Create a client
+                client = data_fusion_v1.DataFusionClient()
+
+                # Initialize request argument(s)
+                request = data_fusion_v1.GetInstanceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_instance(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.data_fusion_v1.types.GetInstanceRequest, dict]):
                 The request object. Request message for getting details
@@ -373,6 +470,31 @@ class DataFusionAsyncClient:
         r"""Creates a new Data Fusion instance in the specified
         project and location.
 
+
+        .. code-block:: python
+
+            from google.cloud import data_fusion_v1
+
+            def sample_create_instance():
+                # Create a client
+                client = data_fusion_v1.DataFusionClient()
+
+                # Initialize request argument(s)
+                request = data_fusion_v1.CreateInstanceRequest(
+                    parent="parent_value",
+                    instance_id="instance_id_value",
+                )
+
+                # Make the request
+                operation = client.create_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.data_fusion_v1.types.CreateInstanceRequest, dict]):
                 The request object. Request message for creating a Data
@@ -413,7 +535,7 @@ class DataFusionAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, instance, instance_id])
         if request is not None and has_flattened_params:
@@ -472,6 +594,29 @@ class DataFusionAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single Date Fusion instance.
 
+        .. code-block:: python
+
+            from google.cloud import data_fusion_v1
+
+            def sample_delete_instance():
+                # Create a client
+                client = data_fusion_v1.DataFusionClient()
+
+                # Initialize request argument(s)
+                request = data_fusion_v1.DeleteInstanceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.data_fusion_v1.types.DeleteInstanceRequest, dict]):
                 The request object. Request message for deleting a Data
@@ -510,7 +655,7 @@ class DataFusionAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -566,6 +711,32 @@ class DataFusionAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates a single Data Fusion instance.
 
+        .. code-block:: python
+
+            from google.cloud import data_fusion_v1
+
+            def sample_update_instance():
+                # Create a client
+                client = data_fusion_v1.DataFusionClient()
+
+                # Initialize request argument(s)
+                instance = data_fusion_v1.Instance()
+                instance.type_ = "DEVELOPER"
+
+                request = data_fusion_v1.UpdateInstanceRequest(
+                    instance=instance,
+                )
+
+                # Make the request
+                operation = client.update_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.data_fusion_v1.types.UpdateInstanceRequest, dict]):
                 The request object. Request message for updating a Data
@@ -611,7 +782,7 @@ class DataFusionAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([instance, update_mask])
         if request is not None and has_flattened_params:
@@ -670,6 +841,30 @@ class DataFusionAsyncClient:
         r"""Restart a single Data Fusion instance.
         At the end of an operation instance is fully restarted.
 
+
+        .. code-block:: python
+
+            from google.cloud import data_fusion_v1
+
+            def sample_restart_instance():
+                # Create a client
+                client = data_fusion_v1.DataFusionClient()
+
+                # Initialize request argument(s)
+                request = data_fusion_v1.RestartInstanceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.restart_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.data_fusion_v1.types.RestartInstanceRequest, dict]):
                 The request object. Request message for restarting a
