@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -58,8 +58,7 @@ class NetworkConfig(proto.Message):
             executing pipelines. In case of shared VPC where
             the network resides in another host project the
             network should specified in the form of
-            projects/{host-project-
-            id}/global/networks/{network}
+            projects/{host-project-id}/global/networks/{network}
         ip_allocation (str):
             The IP range in CIDR notation to use for the
             managed Data Fusion instance nodes. This range
